@@ -1405,14 +1405,10 @@ quick_lounge_load_uri_sync (QuickLounge  *quick_lounge,
 
 	for (scan = files; scan; scan = scan->next) {
 		char *uri = scan->data;
-		char *command;
-
-		command = g_strdup_printf ("echo \"load %s\" >> /home/pippo/ql_log", uri);
-		system (command);
-		g_free (command);
 
 		if (*uri == 0)  
 			quick_box_add_separator (quick_box, -1);
+
 		else if (is_desktop_file (uri))
 			quick_box_add_button (quick_box, uri, -1);
 	}
